use dioxus::prelude::*;

use crate::util::model::user::User;

pub fn Users() -> Element {
    let users = use_resource(fetch_users);

    rsx! {
        div {
            class: "flex justify-center",
            div {
                class: "max-w-4xl w-full",
                h2 { class: "font-bold text-lg", "Gebruikers" },
                match &*users.read_unchecked() {
                    Some(Ok(res)) => rsx! {
                        div {
                            class: "overflow-x-auto",
                            table {
                                class: "table table-zebra table-pin-rows",
                                thead {
                                    tr {
                                        th { "Id" }
                                        th { "Email" }
                                    }
                                }
                                tbody {
                                    for user in res {
                                        UserRow { user: user.clone() }
                                    }
                                }
                            }
                        }
                    },
                    Some(Err(_)) => rsx! { div { "Error while loading users" } },
                    None => rsx! { div { "Loading..." } },
                }
            }
        }
    }
}

#[derive(Props, Clone, PartialEq)]
struct UserRowProps {
    user: User,
}

fn UserRow(props: UserRowProps) -> Element {
    rsx! {
        tr {
            class: "hover hover:cursor-pointer",
            th { "{props.user.id}" }
            td { "{props.user.email}" }
       }
    }
}

#[server]
async fn fetch_users() -> Result<Vec<User>, ServerFnError> {
    let users = User::fetch_all().await?;
    Ok(users)
}
